@@ -115,7 +115,7 @@ function DBconnect(&$error) {
 					}
 				}
 
-				$DB['DB'] = @oci_connect($DB['USER'], $DB['PASSWORD'], $connect);
+				$DB['DB'] = @oci_connect($DB['USER'], $DB['PASSWORD'], $connect, 'UTF8');
 				if ($DB['DB']) {
 					DBexecute('ALTER SESSION SET NLS_NUMERIC_CHARACTERS='.zbx_dbstr('. '));
 				}
@@ -169,28 +169,6 @@ function DBconnect(&$error) {
 					$dbBackend = new Db2DbBackend();
 				}
 				break;
-			case ZBX_DB_SQLITE3:
-				if (file_exists($DB['DATABASE'])) {
-					init_sqlite3_access();
-					lock_sqlite3_access();
-					try{
-						$DB['DB'] = @new SQLite3($DB['DATABASE'], SQLITE3_OPEN_READWRITE);
-					}
-					catch (Exception $e) {
-						$error = 'Error connecting to database.';
-						$result = false;
-					}
-					unlock_sqlite3_access();
-				}
-				else {
-					$error = 'Missing database';
-					$result = false;
-				}
-
-				if ($result) {
-					$dbBackend = new SqliteDbBackend();
-				}
-				break;
 			default:
 				$error = 'Unsupported database';
 				$result = false;
@@ -206,6 +184,10 @@ function DBconnect(&$error) {
 		$DB['DB'] = null;
 	}
 
+	if (!$result && !ZBX_SHOW_SQL_ERRORS) {
+		$error = _('SQL error. Please contact Zabbix administrator.');
+	}
+
 	return $result;
 }
 
@@ -228,12 +210,6 @@ function DBclose() {
 			case ZBX_DB_DB2:
 				$result = db2_close($DB['DB']);
 				break;
-			case ZBX_DB_SQLITE3:
-				lock_sqlite3_access();
-				$DB['DB']->close();
-				unlock_sqlite3_access();
-				$result = true;
-				break;
 		}
 	}
 	unset($DB['DB']);
@@ -270,10 +246,6 @@ function DBstart() {
 		case ZBX_DB_DB2:
 			$result = db2_autocommit($DB['DB'], DB2_AUTOCOMMIT_OFF);
 			break;
-		case ZBX_DB_SQLITE3:
-			lock_sqlite3_access();
-			$result = DBexecute('BEGIN');
-			break;
 	}
 	return $result;
 }
@@ -334,10 +306,6 @@ function DBcommit() {
 				db2_autocommit($DB['DB'], DB2_AUTOCOMMIT_ON);
 			}
 			break;
-		case ZBX_DB_SQLITE3:
-			$result = DBexecute('COMMIT');
-			unlock_sqlite3_access();
-			break;
 	}
 	return $result;
 }
@@ -361,10 +329,6 @@ function DBrollback() {
 			$result = db2_rollback($DB['DB']);
 			db2_autocommit($DB['DB'], DB2_AUTOCOMMIT_ON);
 			break;
-		case ZBX_DB_SQLITE3:
-			$result = DBexecute('ROLLBACK');
-			unlock_sqlite3_access();
-			break;
 	}
 	return $result;
 }
@@ -402,22 +366,22 @@ function DBselect($query, $limit = null, $offset = 0) {
 	switch ($DB['TYPE']) {
 		case ZBX_DB_MYSQL:
 			if (!$result = mysqli_query($DB['DB'], $query)) {
-				error('Error in query ['.$query.'] ['.mysqli_error($DB['DB']).']');
+				sqlError('Error in query ['.$query.'] ['.mysqli_error($DB['DB']).']');
 			}
 			break;
 		case ZBX_DB_POSTGRESQL:
 			if (!$result = pg_query($DB['DB'], $query)) {
-				error('Error in query ['.$query.'] ['.pg_last_error().']');
+				sqlError('Error in query ['.$query.'] ['.pg_last_error().']');
 			}
 			break;
 		case ZBX_DB_ORACLE:
 			if (!$result = oci_parse($DB['DB'], $query)) {
 				$e = @oci_error();
-				error('SQL error ['.$e['message'].'] in ['.$e['sqltext'].']');
+				sqlError('SQL error ['.$e['message'].'] in ['.$e['sqltext'].']');
 			}
 			elseif (!@oci_execute($result, ($DB['TRANSACTIONS'] ? OCI_DEFAULT : OCI_COMMIT_ON_SUCCESS))) {
 				$e = oci_error($result);
-				error('SQL error ['.$e['message'].'] in ['.$e['sqltext'].']');
+				sqlError('SQL error ['.$e['message'].'] in ['.$e['sqltext'].']');
 			}
 			break;
 		case ZBX_DB_DB2:
@@ -428,25 +392,14 @@ function DBselect($query, $limit = null, $offset = 0) {
 
 			if (!$result = db2_prepare($DB['DB'], $query)) {
 				$e = @db2_stmt_errormsg($result);
-				error('SQL error ['.$query.'] in ['.$e.']');
+				sqlError('SQL error ['.$query.'] in ['.$e.']');
 			}
 			elseif (true !== @db2_execute($result, $options)) {
 				$e = @db2_stmt_errormsg($result);
-				error('SQL error ['.$query.'] in ['.$e.']');
+				sqlError('SQL error ['.$query.'] in ['.$e.']');
 				$result = false;
 			}
 			break;
-		case ZBX_DB_SQLITE3:
-			if ($DB['TRANSACTIONS'] == 0) {
-				lock_sqlite3_access();
-			}
-			if (false === ($result = $DB['DB']->query($query))) {
-				error('Error in query ['.$query.'] Error code ['.$DB['DB']->lastErrorCode().'] Message ['.$DB['DB']->lastErrorMsg().']');
-			}
-			if ($DB['TRANSACTIONS'] == 0) {
-				unlock_sqlite3_access();
-			}
-			break;
 	}
 
 	// $result is false only if an error occurred
@@ -488,7 +441,7 @@ function DBaddLimit($query, $limit = 0, $offset = 0) {
 
 	if ((isset($limit) && ($limit < 0 || !zbx_ctype_digit($limit))) || $offset < 0 || !zbx_ctype_digit($offset)) {
 		$moreDetails = isset($limit) ? ' Limit ['.$limit.'] Offset ['.$offset.']' : ' Offset ['.$offset.']';
-		error('Incorrect parameters for limit and/or offset. Query ['.$query.']'.$moreDetails);
+		sqlError('Incorrect parameters for limit and/or offset. Query ['.$query.']'.$moreDetails);
 
 		return false;
 	}
@@ -498,8 +451,8 @@ function DBaddLimit($query, $limit = 0, $offset = 0) {
 		switch ($DB['TYPE']) {
 			case ZBX_DB_MYSQL:
 			case ZBX_DB_POSTGRESQL:
-			case ZBX_DB_SQLITE3:
-				$query .= ' LIMIT '.intval($limit).' OFFSET '.intval($offset);
+				$query .= ' LIMIT '.intval($limit);
+				$query .= $offset != 0 ? ' OFFSET '.intval($offset) : '';
 				break;
 			case ZBX_DB_ORACLE:
 			case ZBX_DB_DB2:
@@ -527,22 +480,22 @@ function DBexecute($query, $skip_error_messages = 0) {
 	switch ($DB['TYPE']) {
 		case ZBX_DB_MYSQL:
 			if (!$result = mysqli_query($DB['DB'], $query)) {
-				error('Error in query ['.$query.'] ['.mysqli_error($DB['DB']).']');
+				sqlError('Error in query ['.$query.'] ['.mysqli_error($DB['DB']).']');
 			}
 			break;
 		case ZBX_DB_POSTGRESQL:
 			if (!$result = (bool) pg_query($DB['DB'], $query)) {
-				error('Error in query ['.$query.'] ['.pg_last_error().']');
+				sqlError('Error in query ['.$query.'] ['.pg_last_error().']');
 			}
 			break;
 		case ZBX_DB_ORACLE:
 			if (!$result = oci_parse($DB['DB'], $query)) {
 				$e = @oci_error();
-				error('SQL error ['.$e['message'].'] in ['.$e['sqltext'].']');
+				sqlError('SQL error ['.$e['message'].'] in ['.$e['sqltext'].']');
 			}
 			elseif (!@oci_execute($result, ($DB['TRANSACTIONS'] ? OCI_DEFAULT : OCI_COMMIT_ON_SUCCESS))) {
 				$e = oci_error($result);
-				error('SQL error ['.$e['message'].'] in ['.$e['sqltext'].']');
+				sqlError('SQL error ['.$e['message'].'] in ['.$e['sqltext'].']');
 			}
 			else {
 				$result = true; // function must return boolean
@@ -551,27 +504,16 @@ function DBexecute($query, $skip_error_messages = 0) {
 		case ZBX_DB_DB2:
 			if (!$result = db2_prepare($DB['DB'], $query)) {
 				$e = @db2_stmt_errormsg($result);
-				error('SQL error ['.$query.'] in ['.$e.']');
+				sqlError('SQL error ['.$query.'] in ['.$e.']');
 			}
 			elseif (true !== @db2_execute($result)) {
 				$e = @db2_stmt_errormsg($result);
-				error('SQL error ['.$query.'] in ['.$e.']');
+				sqlError('SQL error ['.$query.'] in ['.$e.']');
 			}
 			else {
 				$result = true; // function must return boolean
 			}
 			break;
-		case ZBX_DB_SQLITE3:
-			if ($DB['TRANSACTIONS'] == 0) {
-				lock_sqlite3_access();
-			}
-			if (!$result = $DB['DB']->exec($query)) {
-				error('Error in query ['.$query.'] Error code ['.$DB['DB']->lastErrorCode().'] Message ['.$DB['DB']->lastErrorMsg().']');
-			}
-			if ($DB['TRANSACTIONS'] == 0) {
-				unlock_sqlite3_access();
-			}
-			break;
 	}
 	if ($DB['TRANSACTIONS'] != 0 && !$result) {
 		$DB['TRANSACTION_NO_FAILED_SQLS'] = false;
@@ -641,25 +583,6 @@ function DBfetch($cursor, $convertNulls = true) {
 				unset($value);
 			}
 			break;
-		case ZBX_DB_SQLITE3:
-			if ($DB['TRANSACTIONS'] == 0) {
-				lock_sqlite3_access();
-			}
-			if (!$result = $cursor->fetchArray(SQLITE3_ASSOC)) {
-				unset($cursor);
-			}
-			else {
-				// cast all of the values to string to be consistent with other DB drivers: all of them return
-				// only strings.
-				foreach ($result as &$value) {
-					$value = (string) $value;
-				}
-				unset($value);
-			}
-			if ($DB['TRANSACTIONS'] == 0) {
-				unlock_sqlite3_access();
-			}
-			break;
 	}
 
 	if ($result) {
@@ -678,14 +601,7 @@ function DBfetch($cursor, $convertNulls = true) {
 }
 
 function zbx_sql_mod($x, $y) {
-	global $DB;
-
-	switch ($DB['TYPE']) {
-		case ZBX_DB_SQLITE3:
-			return ' (('.$x.') % ('.$y.'))';
-		default:
-			return ' MOD('.$x.','.$y.')';
-	}
+	return ' MOD('.$x.','.$y.')';
 }
 
 function get_dbid($table, $field) {
@@ -763,8 +679,8 @@ function zbx_db_search($table, $options, &$sql_parts) {
 		info(_s('Error in search request for table "%1$s".', $table));
 	}
 
-	$start = is_null($options['startSearch']) ? '%' : '';
-	$exclude = is_null($options['excludeSearch']) ? '' : ' NOT ';
+	$start = $options['startSearch'] ? '' : '%';
+	$exclude = $options['excludeSearch'] ? ' NOT ' : '';
 	$glue = (!$options['searchByAny']) ? ' AND ' : ' OR ';
 
 	$search = [];
@@ -861,10 +777,11 @@ function check_db_fields($dbFields, &$args) {
  * @param array  $values		array of numerical values sorted in ascending order to be included in WHERE
  * @param bool   $notIn			builds inverted condition
  * @param bool   $sort			values mandatory must be sorted
+ * @param bool   $quote
  *
  * @return string
  */
-function dbConditionInt($fieldName, array $values, $notIn = false, $sort = true) {
+function dbConditionInt($fieldName, array $values, $notIn = false, $sort = true, $quote = true) {
 	$MAX_EXPRESSIONS = 950; // maximum  number of values for using "IN (id1>,<id2>,...,<idN>)"
 	$MIN_NUM_BETWEEN = 4; // minimum number of consecutive values for using "BETWEEN <id1> AND <idN>"
 
@@ -923,7 +840,9 @@ function dbConditionInt($fieldName, array $values, $notIn = false, $sort = true)
 		$operatorNot = $notIn ? 'NOT ' : '';
 
 		foreach ($betweens as $between) {
-			$between = $operatorNot.$fieldName.' BETWEEN '.zbx_dbstr($between[0]).' AND '.zbx_dbstr(end($between));
+			$between = $quote
+				? $operatorNot.$fieldName.' BETWEEN '.zbx_dbstr($between[0]).' AND '.zbx_dbstr(end($between))
+				: $operatorNot.$fieldName.' BETWEEN '.$between[0].' AND '.end($between);
 
 			$condition .= $condition ? $operatorAnd.$between : $between;
 		}
@@ -932,7 +851,9 @@ function dbConditionInt($fieldName, array $values, $notIn = false, $sort = true)
 	if ($dataSize == 1) {
 		$operator = $notIn ? '!=' : '=';
 
-		$condition .= ($condition ? $operatorAnd : '').$fieldName.$operator.zbx_dbstr($data[0]);
+		$condition .= $quote
+			? ($condition ? $operatorAnd : '').$fieldName.$operator.zbx_dbstr($data[0])
+			: ($condition ? $operatorAnd : '').$fieldName.$operator.$data[0];
 	}
 	else {
 		$operatorNot = $notIn ? ' NOT' : '';
@@ -942,7 +863,7 @@ function dbConditionInt($fieldName, array $values, $notIn = false, $sort = true)
 			$chunkIns = '';
 
 			foreach ($chunk as $value) {
-				$chunkIns .= ','.zbx_dbstr($value);
+				$chunkIns .= $quote ? ','.zbx_dbstr($value) : ','.$value;
 			}
 
 			$chunkIns = $fieldName.$operatorNot.' IN ('.substr($chunkIns, 1).')';
@@ -1036,42 +957,6 @@ function DBfetchColumn($cursor, $column, $asHash = false) {
 	return $result;
 }
 
-/**
- * Initialize access to SQLite3 database.
- *
- * The function creates a semaphore for exclusive SQLite3 access. It is
- * shared between Zabbix front-end and Zabbix Server.
- *
- * @return bool
- */
-function init_sqlite3_access() {
-	global $DB;
-
-	$DB['SEM_ID'] = sem_get(ftok($DB['DATABASE'], 'z'), 1, 0660);
-}
-
-/**
- * Get exclusive lock on SQLite3 database.
- *
- * @return bool
- */
-function lock_sqlite3_access() {
-	global $DB;
-
-	sem_acquire($DB['SEM_ID']);
-}
-
-/**
- * Release exclusive lock on SQLite3 database.
- *
- * @return bool
- */
-function unlock_sqlite3_access() {
-	global $DB;
-
-	sem_release($DB['SEM_ID']);
-}
-
 /**
  * Returns true if both IDs are equal.
  *
@@ -1097,7 +982,7 @@ function pg_connect_escape($string) {
 
 /**
  * Escape string for safe usage in SQL queries.
- * Works for ibmdb2, mysql, oracle, postgresql, sqlite.
+ * Works for ibmdb2, mysql, oracle, postgresql.
  *
  * @param array|string $var
  *
@@ -1147,15 +1032,6 @@ function zbx_dbstr($var) {
 			}
 			return "'".pg_escape_string($var)."'";
 
-		case ZBX_DB_SQLITE3:
-			if (is_array($var)) {
-				foreach ($var as $vnum => $value) {
-					$var[$vnum] = "'".$DB['DB']->escapeString($value)."'";
-				}
-				return $var;
-			}
-			return "'".$DB['DB']->escapeString($var)."'";
-
 		default:
 			return false;
 	}
@@ -1163,7 +1039,7 @@ function zbx_dbstr($var) {
 
 /**
  * Creates db dependent string with sql expression that casts passed value to bigint.
- * Works for ibmdb2, mysql, oracle, postgresql, sqlite.
+ * Works for ibmdb2, mysql, oracle, postgresql.
  *
  * @param int $field
  *
@@ -1179,7 +1055,6 @@ function zbx_dbcast_2bigint($field) {
 	switch ($DB['TYPE']) {
 		case ZBX_DB_DB2:
 		case ZBX_DB_POSTGRESQL:
-		case ZBX_DB_SQLITE3:
 			return 'CAST('.$field.' AS BIGINT)';
 
 		case ZBX_DB_MYSQL:
